==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QItemEditorCreatorBase_shell.cpp <==
#include "QItemEditorCreatorBase_shell.h"
#include <QtJambi/Cast>

void deleter_QItemEditorCreatorBase(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QItemEditorCreatorBase")
    QItemEditorCreatorBase *_ptr = reinterpret_cast<QItemEditorCreatorBase *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QItemEditorCreatorBase_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QItemEditorCreatorBase_shell) ); }

jmethodID QItemEditorCreatorBase_shell::__shell_javaMethod(int pos) const { return QItemEditorCreatorBase_shell::__shell()->javaMethod(typeid(QItemEditorCreatorBase), pos); }

// emitting (writeShellConstructor)
QItemEditorCreatorBase_shell::QItemEditorCreatorBase_shell()
    : QItemEditorCreatorBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QItemEditorCreatorBase::QItemEditorCreatorBase_shell()", QItemEditorCreatorBase_shell::__shell())
    QItemEditorCreatorBase_shell::__shell()->constructed(typeid(QItemEditorCreatorBase));
}

// emitting (writeShellDestructor)
QItemEditorCreatorBase_shell::~QItemEditorCreatorBase_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QItemEditorCreatorBase::~QItemEditorCreatorBase()", QItemEditorCreatorBase_shell::__shell())
    QItemEditorCreatorBase_shell::__shell()->destructed(typeid(QItemEditorCreatorBase));
}

void QItemEditorCreatorBase_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QItemEditorCreatorBase_shell*>(ptr)->QItemEditorCreatorBase_shell::__shell()->tryDeleteShell(typeid(QItemEditorCreatorBase));
}

// emitting Virtual overrides (virtualFunctions)
QWidget* QItemEditorCreatorBase_shell::createWidget(QWidget* parent0) const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QItemEditorCreatorBase::", QItemEditorCreatorBase_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QWidget*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QItemEditorCreatorBase_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_parent0 = qtjambi_cast<jobject>(__jni_env, parent0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_parent0);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_parent0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QWidget* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnershipForTopLevelObject(__jni_env, __qt_return_value);
                } else {
                    QItemEditorCreatorBase_shell::__shell()->warnForMethod("QItemEditorCreatorBase::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QItemEditorCreatorBase::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return nullptr;
        }
    }else{
        return nullptr;
    }
}

QByteArray QItemEditorCreatorBase_shell::valuePropertyName() const
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QItemEditorCreatorBase::", QItemEditorCreatorBase_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QByteArray  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QItemEditorCreatorBase_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QByteArray >(__jni_env, __java_return_value);
                } else {
                    QItemEditorCreatorBase_shell::__shell()->warnForMethod("QItemEditorCreatorBase::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QItemEditorCreatorBase::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QByteArray();
        }
    }else{
        return QByteArray();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QItemEditorCreatorBase_access::__qt_createWidget_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QWidget* __qt_parent0 = QtJambiAPI::objectFromNativeId<QWidget>(parent0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QItemEditorCreatorBase::createWidget(QWidget * parent) const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QItemEditorCreatorBase::createWidget(QWidget * parent) const.";
    } else {
        QWidget* __qt_return_value = createWidget(__qt_parent0);
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
        return __java_return_value;
    }
}

jobject QItemEditorCreatorBase_access::__qt_valuePropertyName(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QItemEditorCreatorBase::valuePropertyName() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QItemEditorCreatorBase::valuePropertyName() const.";
    } else {
        QByteArray __qt_return_value = valuePropertyName();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new 
void __qt_construct_QItemEditorCreatorBase_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QItemEditorCreatorBase *__qt_this = new(__qtjambi_ptr) QItemEditorCreatorBase_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QItemEditorCreatorBase_shell
void __qt_destruct_QItemEditorCreatorBase(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QItemEditorCreatorBase")
    reinterpret_cast<QItemEditorCreatorBase_shell*>(ptr)->~QItemEditorCreatorBase_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QItemEditorCreatorBase::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QItemEditorCreatorBase_00024Impl_initialize_1native__Lio_qt_widgets_QItemEditorCreatorBase_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QItemEditorCreatorBase::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QItemEditorCreatorBase_0, sizeof(QItemEditorCreatorBase_shell), typeid(QItemEditorCreatorBase), true, &deleter_QItemEditorCreatorBase, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QItemEditorCreatorBase::createWidget(QWidget*)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QItemEditorCreatorBase_00024Impl_00024ConcreteWrapper_createWidget_1native_1QWidget_1ptr_1constfct__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID parent0)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QItemEditorCreatorBase *__qt_this = QtJambiAPI::interfaceFromNativeId<QItemEditorCreatorBase>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QItemEditorCreatorBase::createWidget(QWidget*)const", __qt_this)
        __java_return_value = static_cast<const QItemEditorCreatorBase_access*>(__qt_this)->__qt_createWidget_QWidget_ptr_constfct(__jni_env, __this_nativeId, parent0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QItemEditorCreatorBase::valuePropertyName()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QItemEditorCreatorBase_00024Impl_00024ConcreteWrapper_valuePropertyName_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QItemEditorCreatorBase *__qt_this = QtJambiAPI::interfaceFromNativeId<QItemEditorCreatorBase>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QItemEditorCreatorBase::valuePropertyName()const", __qt_this)
        __java_return_value = static_cast<const QItemEditorCreatorBase_access*>(__qt_this)->__qt_valuePropertyName(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QItemEditorCreatorBase(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QItemEditorCreatorBase>("QItemEditorCreatorBase", "io/qt/widgets/QItemEditorCreatorBase");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "createWidget", "(Lio/qt/widgets/QWidget;)Lio/qt/widgets/QWidget;", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "valuePropertyName", "()Lio/qt/core/QByteArray;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QItemEditorCreatorBase, {
        ConstructorInfo(&__qt_construct_QItemEditorCreatorBase_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QItemEditorCreatorBase);
    registerSizeOfShell(typeId, sizeof(QItemEditorCreatorBase_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QItemEditorCreatorBase* _object = dynamic_cast<QItemEditorCreatorBase*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QItemEditorCreatorBase *object = reinterpret_cast<QItemEditorCreatorBase *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QItemEditorCreatorBase *object = reinterpret_cast<const QItemEditorCreatorBase *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QItemEditorCreatorBase_shell.cpp <==
#include "QItemEditorCreatorBase_shell.h"
#include <QtJambi/Cast>

void deleter_QItemEditorCreatorBase(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QItemEditorCreatorBase")
    QItemEditorCreatorBase *_ptr = reinterpret_cast<QItemEditorCreatorBase *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QItemEditorCreatorBase_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QItemEditorCreatorBase_shell) ); }

jmethodID QItemEditorCreatorBase_oshell::__shell_javaMethod(int pos) const { return QItemEditorCreatorBase_shell::__shell()->javaMethod(typeid(QItemEditorCreatorBase), pos); }

// emitting (writeShellDestructor)
QItemEditorCreatorBase_shell::~QItemEditorCreatorBase_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QItemEditorCreatorBase::~QItemEditorCreatorBase()", this)
    QItemEditorCreatorBase_shell::__shell()->destructed(typeid(QItemEditorCreatorBase));
}

// emitting (writeShellConstructor)
QItemEditorCreatorBase_shell::QItemEditorCreatorBase_shell()
    : QItemEditorCreatorBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QItemEditorCreatorBase::QItemEditorCreatorBase_shell()", this)
    QItemEditorCreatorBase_shell::__shell()->constructed(typeid(QItemEditorCreatorBase));
}

void QItemEditorCreatorBase_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QItemEditorCreatorBase_oshell*>(ptr)->QItemEditorCreatorBase_oshell::__shell()->tryDeleteShell(typeid(QItemEditorCreatorBase));
}

// emitting Virtual overrides (virtualFunctions)
QWidget* QItemEditorCreatorBase_oshell::createWidget(QWidget* parent0) const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QItemEditorCreatorBase::createWidget(QWidget*)const", this)
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QWidget*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QItemEditorCreatorBase_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_parent0 = qtjambi_cast<jobject>(__jni_env, parent0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_parent0);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_parent0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QWidget*>(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnershipForTopLevelObject(__jni_env, __qt_return_value);
                } else {
                    QItemEditorCreatorBase_shell::__shell()->warnForMethod("QItemEditorCreatorBase::createWidget(QWidget*)const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QItemEditorCreatorBase::createWidget(QWidget*)const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return nullptr;
        }
    }else{
        return nullptr;
    }
}

QByteArray QItemEditorCreatorBase_oshell::valuePropertyName() const
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QItemEditorCreatorBase::valuePropertyName()const", this)
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QByteArray  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QItemEditorCreatorBase_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QByteArray>(__jni_env, __java_return_value);
                } else {
                    QItemEditorCreatorBase_shell::__shell()->warnForMethod("QItemEditorCreatorBase::valuePropertyName()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QItemEditorCreatorBase::valuePropertyName()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QByteArray();
        }
    }else{
        return QByteArray();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QItemEditorCreatorBase_access::__qt_createWidget_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QWidget* __qt_parent0 = QtJambiAPI::objectFromNativeId<QWidget>(parent0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QItemEditorCreatorBase::createWidget(QWidget * parent) const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QItemEditorCreatorBase::createWidget(QWidget * parent) const.";
    } else {
        QWidget* __qt_return_value = createWidget(__qt_parent0);
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
        return __java_return_value;
    }
}

jobject QItemEditorCreatorBase_access::__qt_valuePropertyName_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QItemEditorCreatorBase::valuePropertyName() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QItemEditorCreatorBase::valuePropertyName() const.";
    } else {
        QByteArray __qt_return_value = valuePropertyName();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new QItemEditorCreatorBase()
void __qt_construct_QItemEditorCreatorBase(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QItemEditorCreatorBase()")
    Q_UNUSED(__java_arguments)
    QItemEditorCreatorBase *__qt_this = new(__qtjambi_ptr) QItemEditorCreatorBase_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QItemEditorCreatorBase::QItemEditorCreatorBase()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QItemEditorCreatorBase_00024Impl_initialize_1native__Lio_qt_widgets_QItemEditorCreatorBase_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QItemEditorCreatorBase::QItemEditorCreatorBase()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QItemEditorCreatorBase, sizeof(QItemEditorCreatorBase_shell), typeid(QItemEditorCreatorBase), 0, true, &deleter_QItemEditorCreatorBase, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QItemEditorCreatorBase_shell
void __qt_destruct_QItemEditorCreatorBase(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QItemEditorCreatorBase")
    reinterpret_cast<QItemEditorCreatorBase_shell*>(ptr)->~QItemEditorCreatorBase_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QItemEditorCreatorBase::createWidget(QWidget*)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QItemEditorCreatorBase_00024Impl_00024ConcreteWrapper_createWidget_1native_1QWidget_1ptr_1constfct__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID parent0)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QItemEditorCreatorBase *__qt_this = QtJambiAPI::interfaceFromNativeId<QItemEditorCreatorBase>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QItemEditorCreatorBase::createWidget(QWidget*)const", __this_nativeId)
        __java_return_value = static_cast<const QItemEditorCreatorBase_access*>(__qt_this)->__qt_createWidget_QWidget_ptr_constfct(__jni_env, __this_nativeId, parent0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QItemEditorCreatorBase::valuePropertyName()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QItemEditorCreatorBase_00024Impl_00024ConcreteWrapper_valuePropertyName_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QItemEditorCreatorBase *__qt_this = QtJambiAPI::interfaceFromNativeId<QItemEditorCreatorBase>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QItemEditorCreatorBase::valuePropertyName()const", __this_nativeId)
        __java_return_value = static_cast<const QItemEditorCreatorBase_access*>(__qt_this)->__qt_valuePropertyName_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QItemEditorCreatorBase(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QItemEditorCreatorBase>("QItemEditorCreatorBase", "io/qt/widgets/QItemEditorCreatorBase");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "createWidget", "(Lio/qt/widgets/QWidget;)Lio/qt/widgets/QWidget;", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "valuePropertyName", "()Lio/qt/core/QByteArray;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QItemEditorCreatorBase, {
        ConstructorInfo(&__qt_construct_QItemEditorCreatorBase, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QItemEditorCreatorBase);
    registerSizeOfShell(typeId, sizeof(QItemEditorCreatorBase_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QItemEditorCreatorBase* _object = dynamic_cast<QItemEditorCreatorBase*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QItemEditorCreatorBase *object = reinterpret_cast<QItemEditorCreatorBase *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QItemEditorCreatorBase *object = reinterpret_cast<const QItemEditorCreatorBase *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
